import socket
from tkinter.messagebox import showerror

HOST = "127.0.0.1"
PORT = 1130


class Error(Exception):
    pass


def command(cmnd: str, points=None, s=None) -> str:
    if s != None:
        cmnd.replace("#", "")
        command = f"#{cmnd}\n"
        s.sendall(command.encode("ascii"))
        response = s.recv(1024)
        response_str = response.decode("ascii")
        response_str = response_str.strip()
        if response_str.startswith(f"#{cmnd};"):
            response_str = response_str[len(f"#{cmnd};") :]
        parts = response_str.split(";")
        values = parts[0:]
        values_list = [value.strip() for value in values]
        if points == None:
            return values_list
        if values_list[points] != "":
            return values_list[points]
        else:
            return ""
    else:
        with socket.socket(socket.AF_INET, socket.SOCK_STREAM) as s:
            try:
                s.connect((HOST, PORT))
                cmnd.replace("#", "")
                command = f"#{cmnd}\n"
                s.sendall(command.encode("ascii"))
                response = s.recv(1024)
                response_str = response.decode("ascii")
                response_str = response_str.strip()
                if response_str.startswith(f"#{cmnd};"):
                    response_str = response_str[len(f"#{cmnd};") :]
                parts = response_str.split(";")
                values = parts[0:]
                values_list = [value.strip() for value in values]
                if points == None:
                    return values_list
                if values_list[points] != "":
                    return values_list[points]
                else:
                    return ""
            except ConnectionRefusedError as e:
                raise Error("Aurora not responding")
            except Exception as e:
                raise Error(e)



from setuptools import setup, find_packages


def readme():
    with open("README.md", "r") as f:
        return f.read()


setup(
    name="ivaoauroraconnect",
    version="0.5",
    author="LevLvovich1",
    author_email="levlogvinov@gmail.com",
    description="This is library for work with IVAO Aurora",
    long_description=readme(),
    long_description_content_type="text/markdown",
    url="https://github.com/LevLvovich1/ivaoauroraconnect",
    packages=find_packages(),
    install_requires=[],
    classifiers=[
        "Programming Language :: Python :: 3.13",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    keywords="ivao",
    project_urls={"GitHub": "https://github.com/LevLvovich1/ivaoauroraconnect"},
    python_requires=">=3.13",
)
